@@ -57,7 +57,8 @@ show_ignore_focus_stealing_prevention (GtkWidget *widget)
 {
 	gtk_widget_realize (widget);
 	gtk_widget_show (widget);
-	gtk_window_present_with_time (GTK_WINDOW (widget), gdk_x11_get_server_time (widget->window));
+	gtk_window_present_with_time (GTK_WINDOW (widget),
+		gdk_x11_get_server_time (gtk_widget_get_window (widget)));
 }
 
 static void
@@ -729,6 +730,7 @@ wireless_add_menu_item (NMDevice *device,
 	NMAccessPoint *active_ap = NULL;
 	GSList *connections = NULL, *all, *iter;
 	gboolean wireless_enabled = TRUE;
+	gboolean wireless_hw_enabled = TRUE;
 	GSList *menu_items = NULL;  /* All menu items we'll be adding */
 	NMNetworkMenuItem *item, *active_item = NULL;
 	GtkWidget *widget;
@@ -779,7 +781,11 @@ wireless_add_menu_item (NMDevice *device,
 
 	/* Notify user of unmanaged or unavailable device */
 	wireless_enabled = nm_client_wireless_get_enabled (applet->nm_client);
-	widget = nma_menu_device_get_menu_item (device, applet, wireless_enabled ? NULL : _("wireless is disabled"));
+	wireless_hw_enabled = nm_client_wireless_hardware_get_enabled (applet->nm_client);
+	widget = nma_menu_device_get_menu_item (device, applet,
+	                                        wireless_hw_enabled ?
+	                                            (wireless_enabled ? NULL : _("wireless is disabled")) :
+	                                            _("wireless is disabled by hardware switch"));
 	if (widget) {
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), widget);
 		gtk_widget_show (widget);
@@ -1045,7 +1051,9 @@ idle_check_avail_access_point_notification (gpointer datap)
 	applet_do_notify (applet,
 	                  NOTIFY_URGENCY_LOW,
 	                  _("Wireless Networks Available"),
-	                  _("Click on this icon to connect to a wireless network"),
+	                  applet->notify_actions ?
+	                        _("Click on this icon to connect to a wireless network") :
+	                        _("Use the network menu to connect to a wireless network"),
 	                  "nm-device-wireless",
 	                  "dont-show",
 	                  _("Don't show this message again"),
@@ -1355,6 +1363,13 @@ wireless_dialog_close (gpointer user_data)
 	return FALSE;
 }
 
+static void
+wireless_dialog_destroyed (gpointer data, GObject *dialog_ptr)
+{
+	/* remove the idle function; for not to call wireless_dialog_close() on invalid pointer */
+	g_idle_remove_by_data (dialog_ptr);
+}
+
 static void
 nag_dialog_response_cb (GtkDialog *nag_dialog,
                         gint response,
@@ -1365,6 +1380,7 @@ nag_dialog_response_cb (GtkDialog *nag_dialog,
 	if (response == GTK_RESPONSE_NO) {  /* user opted not to correct the warning */
 		nma_wireless_dialog_set_nag_ignored (wireless_dialog, TRUE);
 		g_idle_add (wireless_dialog_close, wireless_dialog);
+		g_object_weak_ref (G_OBJECT (wireless_dialog), wireless_dialog_destroyed, NULL);
 	}
 }
 
