@@ -15,7 +15,7 @@
  * with this program; if not, write to the Free Software Foundation, Inc.,
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * Copyright (C) 2004 - 2008 Red Hat, Inc.
+ * Copyright (C) 2004 - 2010 Red Hat, Inc.
  * Copyright (C) 2005 - 2008 Novell, Inc.
  */
 
@@ -32,7 +32,6 @@
 #include <gdk/gdkx.h>
 
 #include <gconf/gconf-client.h>
-#include <glade/glade.h>
 #include <dbus/dbus.h>
 #include <dbus/dbus-glib.h>
 #include <net/ethernet.h>
@@ -45,7 +44,7 @@
 #include <nm-device.h>
 #include <NetworkManager.h>
 #include <nm-active-connection.h>
-#include <nm-dbus-settings.h>
+#include <nm-remote-settings-system.h>
 
 #include "applet-dbus-manager.h"
 #include "nma-gconf-settings.h"
@@ -65,6 +64,7 @@ typedef struct
 #define APPLET_PREFS_PATH "/apps/nm-applet"
 #define PREF_DISABLE_CONNECTED_NOTIFICATIONS      APPLET_PREFS_PATH "/disable-connected-notifications"
 #define PREF_DISABLE_DISCONNECTED_NOTIFICATIONS   APPLET_PREFS_PATH "/disable-disconnected-notifications"
+#define PREF_DISABLE_VPN_NOTIFICATIONS            APPLET_PREFS_PATH "/disable-vpn-notifications"
 #define PREF_DISABLE_WIFI_CREATE                  APPLET_PREFS_PATH "/disable-wifi-create"
 #define PREF_SUPPRESS_WIRELESS_NETWORKS_AVAILABLE APPLET_PREFS_PATH "/suppress-wireless-networks-available"
 
@@ -85,23 +85,26 @@ typedef struct
 	GMainLoop *loop;
 	NMClient *nm_client;
 
-	NMDBusSettings *dbus_settings;
+	NMRemoteSettingsSystem *system_settings;
 	NMAGConfSettings *gconf_settings;
 
 	GConfClient *	gconf_client;
-	char	*		glade_file;
+	char	*		ui_file;
 
 	guint update_timestamps_id;
 
+	/* Permissions */
+	NMClientPermissionResult permissions[NM_CLIENT_PERMISSION_LAST + 1];
+
 	/* Device classes */
 	NMADeviceClass *wired_class;
 	NMADeviceClass *wifi_class;
 	NMADeviceClass *gsm_class;
 	NMADeviceClass *cdma_class;
+	NMADeviceClass *bt_class;
 
 	/* Data model elements */
 	guint			update_icon_id;
-	gboolean		icons_loaded;
 
 	GtkIconTheme *	icon_theme;
 	GdkPixbuf *		no_connection_icon;
@@ -113,12 +116,25 @@ typedef struct
 	GdkPixbuf *		wireless_50_icon;
 	GdkPixbuf *		wireless_75_icon;
 	GdkPixbuf *		wireless_100_icon;
+	GdkPixbuf *		secure_lock_icon;
 #define NUM_CONNECTING_STAGES 3
 #define NUM_CONNECTING_FRAMES 11
 	GdkPixbuf *		network_connecting_icons[NUM_CONNECTING_STAGES][NUM_CONNECTING_FRAMES];
 #define NUM_VPN_CONNECTING_FRAMES 14
 	GdkPixbuf *		vpn_connecting_icons[NUM_VPN_CONNECTING_FRAMES];
 	GdkPixbuf *		vpn_lock_icon;
+	GdkPixbuf *		fallback_icon;
+
+	/* Mobiel Broadband icons */
+	GdkPixbuf *		wwan_tower_icon;
+	GdkPixbuf *		mb_tech_1x_icon;
+	GdkPixbuf *		mb_tech_evdo_icon;
+	GdkPixbuf *		mb_tech_gprs_icon;
+	GdkPixbuf *		mb_tech_edge_icon;
+	GdkPixbuf *		mb_tech_umts_icon;
+	GdkPixbuf *		mb_tech_hspa_icon;
+	GdkPixbuf *		mb_roaming_icon;
+	GdkPixbuf *		mb_tech_3g_icon;
 
 	/* Active status icon pixbufs */
 	GdkPixbuf *		icon_layers[ICON_LAYER_MAX + 1];
@@ -128,11 +144,10 @@ typedef struct
 	guint			animation_id;
 
 	/* Direct UI elements */
-	GtkStatusIcon *	status_icon;
-	int				size;
+	GtkStatusIcon * status_icon;
+	int             icon_size;
 
 	GtkWidget *		menu;
-	GtkSizeGroup *	encryption_size_group;
 	char *          tip;
 
 	GtkWidget *		context_menu;
@@ -140,6 +155,8 @@ typedef struct
 	guint           networking_enabled_toggled_id;
 	GtkWidget *		wifi_enabled_item;
 	guint           wifi_enabled_toggled_id;
+	GtkWidget *		wwan_enabled_item;
+	guint           wwan_enabled_toggled_id;
 
 	GtkWidget *     notifications_enabled_item;
 	guint           notifications_enabled_toggled_id;
@@ -147,9 +164,9 @@ typedef struct
 	GtkWidget *		info_menu_item;
 	GtkWidget *		connections_menu_item;
 
-	GladeXML *		info_dialog_xml;
+	GtkBuilder *	info_dialog_ui;
 	NotifyNotification*	notification;
-	gboolean		notify_with_actions;
+	gboolean        notify_actions;
 } NMApplet;
 
 typedef void (*AppletNewAutoConnectionCallback) (NMConnection *connection,
@@ -189,11 +206,12 @@ struct NMADeviceClass {
 	                                        gpointer user_data);
 
 	gboolean       (*get_secrets)          (NMDevice *device,
-	                                        NMConnection *connection,
+	                                        NMSettingsConnectionInterface *connection,
 	                                        NMActiveConnection *active_connection,
 	                                        const char *setting_name,
 	                                        const char **hints,
-	                                        DBusGMethodInvocation *context,
+	                                        NMANewSecretsRequestedFunc callback,
+	                                        gpointer callback_data,
 	                                        NMApplet *applet,
 	                                        GError **error);
 };
@@ -204,11 +222,14 @@ NMApplet *nm_applet_new (GMainLoop *loop);
 
 void applet_schedule_update_icon (NMApplet *applet);
 
-NMSettings *applet_get_settings (NMApplet *applet);
+NMSettingsInterface *applet_get_settings (NMApplet *applet);
 
 GSList *applet_get_all_connections (NMApplet *applet);
 
-GtkWidget *nma_menu_device_check_unusable (NMDevice *device,
+gboolean nma_menu_device_check_unusable (NMDevice *device);
+
+GtkWidget * nma_menu_device_get_menu_item (NMDevice *device,
+                                           NMApplet *applet,
                                            const char *unavailable_msg);
 
 void applet_menu_item_activate_helper (NMDevice *device,
@@ -217,7 +238,20 @@ void applet_menu_item_activate_helper (NMDevice *device,
                                        NMApplet *applet,
                                        gpointer dclass_data);
 
-NMAGConfConnection *applet_get_exported_connection_for_device (NMDevice *device, NMApplet *applet);
+void applet_menu_item_disconnect_helper (NMDevice *device,
+                                         NMApplet *applet);
+
+void applet_menu_item_add_complex_separator_helper (GtkWidget *menu,
+                                                    NMApplet *applet,
+                                                    const gchar* label,
+                                                    int pos);
+
+GtkWidget*
+applet_menu_item_create_device_item_helper (NMDevice *device,
+                                            NMApplet *applet,
+                                            const gchar *text);
+
+NMSettingsConnectionInterface *applet_get_exported_connection_for_device (NMDevice *device, NMApplet *applet);
 
 void applet_do_notify (NMApplet *applet,
                        NotifyUrgency urgency,
@@ -239,4 +273,12 @@ NMConnection * applet_find_active_connection_for_device (NMDevice *device,
                                                          NMApplet *applet,
                                                          NMActiveConnection **out_active);
 
+GtkWidget * applet_new_menu_item_helper (NMConnection *connection,
+                                         NMConnection *active,
+                                         gboolean add_active);
+
+GdkPixbuf * nma_icon_check_and_load (const char *name,
+                                     GdkPixbuf **icon,
+                                     NMApplet *applet);
+
 #endif
